# avoid dependency on X11 libraries
%define without_x       1

%define	cvs	20080216
%if %cvs
%define release %mkrel 0.%cvs.2
%else
%define release %mkrel 1
%endif

Summary:	A user-friendly file manager and visual shell
Name:		mc
Version:	4.6.2
Release:	%{release}
License:	GPLv2+
Group:		File tools
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
URL:		http://www.ibiblio.org/mc/
%if %cvs
# cvs -z3 -d:pserver:anoncvs@cvs.savannah.gnu.org:/cvsroot/mc co mc
Source0:	%{name}-%{cvs}.tar.lzma
%else
Source0:	ftp://ftp.gnome.org:/pub/GNOME/stable/sources/mc/%{name}-%{version}.tar.bz2
%endif

# ** Mandriva patches: 0 - 99 **

# remove copyright tag, and s/serial/epoch tag in rpm vfs
Patch1:		mc-4.6.2-rpm_obsolete_tags.patch
Patch2:		mc-4.6.0-toolbar-po-mdk.path
# (tv) add runlevel to initscript
Patch3:		mc-4.6.0-init.patch
#Patch4:	mc-4.6.0-ptsname.patch
Patch5:		mc-4.6.1-bourne-compliancy.patch
Patch6:		mc-4.6.1-decent_defaults.diff
# from https://savannah.gnu.org/bugs/?16303: improves the 7zip handler
# slightly. Modified not to test for '7z', as we don't package it, 
# only '7za' - AdamW 2007/07
Patch7:		u7z.patch
Patch8:		mc-4.6.1.lzma.patch
Patch9:		mc-4.6.1-xdg.patch

# ** Fedora patchset: 100 - 199 **

# UTF-8 patches, rediffed by AdamW for 20071018 snapshot
Patch100:	mc-utf8.patch
Patch101:	mc-utf8-8bit-hex.patch
# Hostname
Patch102:	mc-userhost.patch
Patch103:	mc-utf8-look-and-feel.patch
# IPv6 support for FTPFS
Patch104:	mc-ipv6.patch
# refresh contents of terminal when resized during time expensive I/O
# operations
Patch105:	mc-refresh.patch
Patch106:	mc-64bit.patch
# correctly concatenate directory and file in concat_dir_and_file()
Patch107:	mc-concat.patch
# display free space correctly for multiple filesystems
Patch108:	mc-showfree.patch
# Update panel contents to avoid actions on deleted files
Patch109:	mc-delcheck.patch
# allow exit command even on non-local filesystems (#202440)
Patch110:	mc-exit.patch
Patch111:	mc-newlinedir.patch
# attempt to fcntl() descriptors appropriately so that subshell
#  doesn't leave them open while execve()ing commands
Patch112:	mc-cloexec.patch
# fix displaying of prompt in subshell
Patch113:	mc-prompt.patch

# ** PLD patchset: 200 - 299 **

Patch200:	mc-spec-syntax.patch
Patch201:	mc-urar.patch
Patch202:	mc-srpm.patch
Patch203:	mc-mc.ext.patch
Patch204:	mc-localenames.patch
Patch205:	mc-nolibs.patch
Patch206:	mc-vhdl-syntax.patch

# From OpenSUSE: fix display of nlinks column in UTF-8 locales
# (#34207, SUSE #194715) - AdamW 2008/01
Patch300:	mc-utf8-nlink.patch

Requires:	groff
BuildRequires:	libext2fs-devel
BuildRequires:	libgpm-devel >= 0.18
BuildRequires:	pam-devel
BuildRequires:	slang-devel
BuildRequires:	glib2-devel
BuildRequires:  autoconf
%if %without_x
%else
BuildRequires:	X11-devel
%endif
%if %cvs
BuildRequires:	gettext-devel
%endif

%description
Midnight Commander is a visual shell much like a file manager, only with way
more features.  It is text mode, but also includes mouse support if you are
running GPM.  Its coolest feature is the ability to ftp, view tar, zip
files, and poke into RPMs for specific files.

%prep
%if %cvs
%setup -q -n %{name}
%else
%setup -q -n %{name}-%{version}
%endif

%patch1 -p1 -b .rpm_obsolete_tags
%patch2 -p1 -b .toolbarpo
%patch3 -p1 -b .initlevel
# fixme: disabled P4
#%%patch4 -p1 -b .ptsname
%patch5 -p1 -b .bourne_compliancy
%patch6 -p0 -b .decent_defaults
%patch7 -p1 -b .u7z
%patch8 -p1 -b .lzma
%patch9 -p1 -b .xdg

%patch100 -p1
%patch101 -p1
%patch102 -p1
%patch103 -p1
%patch104 -p1
%patch105 -p1
%patch106 -p1
%patch107 -p1
%patch108 -p1
%patch109 -p1
%patch110 -p1
%patch111 -p1
%patch112 -p1
%patch113 -p1

%patch200 -p1
%patch201 -p1
cp -f vfs/extfs/{rpm,srpm}
%patch202 -p1
%patch203 -p1
%patch204 -p1
%patch205 -p1
%patch206 -p1

%patch300 -p1 -b .nlink

sed -i 's:|hxx|:|hh|hpp|hxx|:' syntax/Syntax

mv -f po/{no,nb}.po

%build

# Convert translated files to UTF-8: bug #31578 - AdamW 2007/06

pushd doc
# italian is already unicode, leave it out.
for i in es hu pl ru sr; do pushd $i; \
# this is ugly, but assume same encoding as .po file for each language.
iconv --from-code=`grep charset= ../../po/$i.po | cut -c36- | head -c-4 | tr "[:lower:]" "[:upper:]"` --to-code=UTF-8 mc.1.in > mc.1.in.new; \
iconv --from-code=`grep charset= ../../po/$i.po | cut -c36- | head -c-4 | tr "[:lower:]" "[:upper:]"` --to-code=UTF-8 xnc.hlp > xnc.hlp.new; \
mv -f mc.1.in.new mc.1.in; mv -f xnc.hlp.new xnc.hlp; popd; done
popd

pushd lib
# rename zh to zh_TW, which is what it really is (I think)
mv mc.hint.zh mc.hint.zh_TW
perl -pi -e 's,mc.hint.zh,mc.hint.zh_TW,g' Makefile.am
# hardcode the list as we need to leave italian out and it just gets ugly doing it 'smartly'...
for i in cs es hu nl pl ru sr uk zh_TW; \
# this is ugly, but assume same encoding as .po file for each language.
do iconv --from-code=`grep charset= ../po/$i.po | cut -c36- | head -c-4 | tr "[:lower:]" "[:upper:]"` --to-code=UTF-8 mc.hint.$i > mc.hint.$i.new; \
mv -f mc.hint.$i.new mc.hint.$i; done
popd

pushd po
# remove the original .mo files
rm -f *.gmo
# find stuff that's not Unicode already
for i in `file *.po | grep -v Unicode | cut -d: -f1`; \
# convert it: the grep, cut, head, tr grabs the source encoding from the .po file header, there's no other way to find it
do iconv --from-code=`grep charset= $i | cut -c36- | head -c-4 | tr "[:lower:]" "[:upper:]"` --to-code=UTF-8 $i > $i.new; \
# change the header to say UTF-8
mv -f $i.new $i; perl -pi -e 's,charset=.*$,charset=UTF-8\\n",g' $i; done
# regenerate the .mo files
for i in `ls *.po | cut -d. -f1`; do /usr/bin/msgfmt -c --statistics -o $i.gmo $i.po; done
popd

%if %cvs
./autogen.sh
%else
%{__aclocal} -I m4
%{__autoconf}
%{__automake}
%endif

X11_WWW="www-browser" %serverbuild

%configure2_5x \
    --with-debug \
    --without-included-gettext \
    --without-included-slang \
    --with-screen=slang \
    --enable-nls \
    --enable-charset \
    --enable-largefile \
%if %without_x
    --without-x
%endif

# don't use make macro, mc doesn't support parallel compilation
make

%install
rm -rf %{buildroot}

install -d %{buildroot}%{_sysconfdir}/{pam.d,profile.d,X11/wmconfig} %{buildroot}%{_initrddir}

#fix mc-wrapper.sh
perl -p -i -e 's/rm -f \"/rm -rf \"/g' lib/mc-wrapper.sh

%makeinstall

install -m 644 lib/mc.sh %{buildroot}%{_sysconfdir}/profile.d/20mc.sh
install -m 644 lib/mc.csh %{buildroot}%{_sysconfdir}/profile.d/20mc.csh

%{find_lang} %{name}

%clean
rm -rf %{buildroot}


%files -f %{name}.lang
%defattr(-, root, root)
%doc FAQ COPYING NEWS README
%{_bindir}/mc
%{_bindir}/mcedit
%{_bindir}/mcmfmt
%{_bindir}/mcview
%dir %{_libdir}/mc/
%{_libdir}/mc/cons.saver
%{_datadir}/mc/cedit.menu
%{_datadir}/mc/edit.indent.rc
%{_datadir}/mc/edit.spell.rc
%{_datadir}/mc/mc.ext
%{_datadir}/mc/mc.hint
%{_datadir}/mc/mc.hint.*
%{_datadir}/mc/mc.hlp
%{_datadir}/mc/mc.hlp.*
%{_datadir}/mc/mc.lib
%{_datadir}/mc/mc.menu
%{_datadir}/mc/mc.menu.*
%{_datadir}/mc/mc.charsets
%{_datadir}/mc/extfs/*
%{_mandir}/man1/*
%dir %{_datadir}/mc
%dir %{_datadir}/mc/bin
%{_datadir}/mc/bin/*
%{_datadir}/mc/syntax/
#%{_datadir}/mc/term/
%{_sysconfdir}/profile.d/*


%changelog
* Sun Mar 09 2008 Oden Eriksson <oeriksson@mandriva.com> 4.6.2-0.20080216.2mdv2008.1
+ Revision: 182926
- remove one chunk from the decent_defaults patch as it
  triggers some obscure bug...

* Sat Feb 16 2008 Adam Williamson <awilliamson@mandriva.com> 4.6.2-0.20080216.1mdv2008.1
+ Revision: 169325
- update spec-syntax.patch from upstream (PLD)
- drop pld-developerfriendly.patch (not relevant to MDV)
- new snapshot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - fix no-buildroot-tag

* Sat Feb 02 2008 Adam Williamson <awilliamson@mandriva.com> 4.6.2-0.20071018.3mdv2008.1
+ Revision: 161343
- add utf8-nlink.patch (from OpenSUSE, fixes display of nlinks colum - #34207)

* Sat Dec 22 2007 Guillaume Rousse <guillomovitch@mandriva.org> 4.6.2-0.20071018.2mdv2008.1
+ Revision: 137217
- no executable bit on profile scriptlets
  order prefix on profile scriptlets

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request
    - buildrequires X11-devel instead of XFree86-devel

* Fri Oct 19 2007 Adam Williamson <awilliamson@mandriva.com> 4.6.2-0.20071018.1mdv2008.1
+ Revision: 100135
- buildrequires gettext-devel for CVS build
- remove now unnecessary u7z workaround
- use %%{buildroot} not $RPM_BUILD_ROOT
- drop incredibly old and apparently useless libcom_err workaround
- completely refresh patch set:
  	+ drop mc-4.6.0-xpdf.patch (superseded by XDG patch)
  	+ drop mc-4.6.1-tempfiles.patch (merged upstream)
  	+ drop mc-4.6.1-2gb.patch (merged upstream)
  	+ drop amc patches (partially merged upstream, PLD dropped them)
  	+ drop mc-mo.patch (PLD dropped it)
  	+ drop mc-fish-upload.patch (merged upstream)
  	+ drop mc-ftpcrash.patch (merged upstream)
  	+ drop mc-symcrash.patch (merged upstream)
  	+ drop mc-slang2.patch (slang2 conversion done upstream)
  	+ drop mc-4.6.1-7zip.patch (merged upstream)
  	+ add several patches from Fedora including updated UTF-8 patch
  	+ add mc-localenames.patch from PLD to rename no to nb (locale)
  	+ add mc-vhdl-syntax.patch from PLD to add VHDL syntax
  	+ refresh all Fedora and PLD patches from latest SRPMs
  	+ rediff all patches where necessary
  	+ rearrange patches in spec to be cleaner and more organized
- update to current CVS snapshot

* Wed Sep 26 2007 Adam Williamson <awilliamson@mandriva.com> 4.6.1-17mdv2008.0
+ Revision: 93022
- add mc-4.6.1-2gb.patch: fixes a bug preventing >2GB ssh file transfers from working (from upstream bug #15524 and Debian bug #349390)

* Wed Sep 19 2007 Adam Williamson <awilliamson@mandriva.com> 4.6.1-16mdv2008.0
+ Revision: 90046
- add mc-4.6.1-tempfiles.patch to fix bug which left temp files lying around (#15687)
- new license policy

* Tue Sep 04 2007 Adam Williamson <awilliamson@mandriva.com> 4.6.1-15mdv2008.0
+ Revision: 79562
- updated version of patch109 from Fedora bug #186456 (fixes Mandriva bug #26498)

* Fri Jul 06 2007 Adam Williamson <awilliamson@mandriva.com> 4.6.1-14mdv2008.0
+ Revision: 48852
- add 7zip VFS handler (from upstream CVS, with patch from Sergey Niskorodov)

* Thu Jun 28 2007 Adam Williamson <awilliamson@mandriva.com> 4.6.1-13mdv2008.0
+ Revision: 45336
- convert xnc.hlp files too

* Thu Jun 28 2007 Adam Williamson <awilliamson@mandriva.com> 4.6.1-12mdv2008.0
+ Revision: 45263
- gotta adjust Makefile for the zh rename
- convert files to unicode a lot more smartly

* Wed Jun 27 2007 Adam Williamson <awilliamson@mandriva.com> 4.6.1-11mdv2008.0
+ Revision: 44886
- patch11: fix some invalid control sequences in zh_TW po
- have to convert headers of po files as well
- convert some translations to UTF-8 (#31542, #31578)

* Tue Jun 19 2007 Adam Williamson <awilliamson@mandriva.com> 4.6.1-10mdv2008.0
+ Revision: 41596
- bump to get it to main

* Sat Jun 09 2007 Adam Williamson <awilliamson@mandriva.com> 4.6.1-9mdv2008.0
+ Revision: 37673
- patch to build against new slag, drop manual slang dependency

* Sat Jun 09 2007 Adam Williamson <awilliamson@mandriva.com> 4.6.1-8mdv2008.0
+ Revision: 37608
- try another way of forcing to build against slang1
- patch201: use xdg-open to open several types of file in X
- drop a silly smiley from the description
- doesn't build with slang 2
- slightly reorder patches for clarity

* Mon Apr 23 2007 Oden Eriksson <oeriksson@mandriva.com> 4.6.1-7mdv2008.0
+ Revision: 17506
- make it work with latest bash (P10)


* Mon Feb 12 2007 Per Øyvind Karlsen <pkarlsen@mandriva.com> 4.6.1-6mdv2007.0
+ Revision: 118891
- add lzma support (P114)

* Thu Nov 02 2006 Oden Eriksson <oeriksson@mandriva.com> 4.6.1-5mdv2007.1
+ Revision: 75591
- Import mc

* Thu Nov 02 2006 Oden Eriksson <oeriksson@mandriva.com> 4.6.1-5mdv2007.1
- bunzip patches

* Fri Aug 25 2006 Oden Eriksson <oeriksson@mandrakesoft.com> 4.6.1-4mdv2007.0
- added P9 to set some defaults
- added PLD patches P100 - P113 (4.6.1-5)

* Fri May 12 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 4.6.1-3mdk
- make mc.sh bash compliant (P8)
- fix executable-marked-as-config-file

* Mon Jan 16 2006 Marcel Pol <mpol@mandriva.org> 4.6.1-2mdk
- remove copyright tag, and s/serial/epoch tag in rpm vfs
  (bug #20662)

* Thu Jul 28 2005 Marcel Pol <mpol@mandriva.org> 4.6.1-1mdk
- 4.6.1 final
- drop P4, fixed upstream
- update P7
- drop P8, merged upstream

* Fri May 06 2005 Marcel Pol <mpol@mandriva.org> 4.6.1-0.pre3.4mdk
- fix logo on help page
- add %%mkrel for backporting

* Fri Apr 22 2005 Marcel Pol <mpol@mandriva.org> 4.6.1-0.pre3.3mdk
- sync utf8 patch7 with Fedora 4.6.1-0.13.FC3

* Sun Feb 13 2005 Marcel Pol <mpol@mandrake.org> 4.6.1-0.pre3.2mdk
- use www-browser

* Sun Feb 13 2005 Marcel Pol <mpol@mandrake.org> 4.6.1-0.pre3.1mdk
- unofficial 4.6.1-pre3
- drop source1, P1, P2, P5, P9, P13, P14, P15, P16, merged upstream
- drop P3, different fix upstream (use id, not $USER)
- rediff P4
- sync utf8 patch with fedora3
  now just one patch; P7, P8, P10, P11, P12 moved into P7
- disable P6 for now
- small cleanups

* Mon Sep 27 2004 Marcel Pol <mpol@mandrake.org> 4.6.0-13mdk
- add requires slang > 1.4.9-5mdk

* Wed Sep 15 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 4.6.0-12mdk
- make the wrapper script work (P3)

* Mon Aug 30 2004 Marcel Pol <mpol@mandrake.org> 4.6.0-11mdk
- security fix for vfs/extfs CAN-2004-0494
- really use gqview for images
- --enable-charset is back
- patch14 add info/obsoletes, info/license to rpm extfs
- patch15 fix crash on use of large syntax file
- patch16 fix coloring of diffs of diffs

* Sat Jul 24 2004 Marcel Pol <mpol@mandrake.org> 4.6.0-10mdk
- again build against new slang
- drop mcserv optional build

* Thu Jul 22 2004 Marcel Pol <mpol@mandrake.org> 4.6.0-9mdk
- update patch1, use gqview for images as upstream does
- add unzip vfs
- drop patch3, merged in patch6 to patch10
- patch5: "secret" redhat cpio fix
- add patch6
- patch7: build against slang-utf8
- patch8, 10, 11, 12: add utf8 patches from fedora/suse
- patch9: (jumbo patch) several fixes, updates, etc.
- disable charset conversion

* Sat May 01 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 4.6.0-8mdk
- Patch3 (stew): security fix for CAN-2004-0226,0231,0232
- Patch4 (stew): disable ta locale - won't compile

* Sun Apr 11 2004 Michael Scherer <misc@mandrake.org> 4.6.0-7mdk 
- [DIRM]

* Tue Feb 17 2004 Marcel Pol <mpol@mandrake.org> 4.6.0-6mdk
- security fix for CAN-2003-1023 (vdanen)

* Mon Feb 16 2004 Marcel Pol <mpol@mandrake.org> 4.6.0-5mdk
- Patch1: image extension s/ee/display (bug #7907)

